@@ -45,7 +45,7 @@ database errors.
 
 import six
 
-from oslo.db.openstack.common.gettextutils import _
+from oslo.db._i18n import _
 
 
 class DBError(Exception):
@@ -163,3 +163,11 @@ class InvalidSortKey(Exception):
 
 class ColumnError(Exception):
     """Error raised when no column or an invalid column is found."""
+
+
+class BackendNotAvailable(Exception):
+    """Error raised when a particular database backend is not available
+
+    within a test suite.
+
+    """
