@@ -23,6 +23,8 @@ from oslo.db.sqlalchemy.compat import handle_error as _h_err
 # flake8 won't let me import handle_error directly
 engine_connect = _e_conn.engine_connect
 handle_error = _h_err.handle_error
-ExceptionContextImpl = _h_err.ExceptionContextImpl
+handle_connect_context = _h_err.handle_connect_context
 
-__all__ = ['engine_connect', 'handle_error', 'ExceptionContextImpl']
+__all__ = [
+    'engine_connect', 'handle_error',
+    'handle_connect_context']
